Coverage for /Users/davegaeddert/Developer/dropseed/plain/plain-auth/plain/auth/default_settings.py: 83%

1 from importlib.util import find_spec

2

3 AUTH_USER_MODEL: str

4 AUTH_LOGIN_URL: str

5

6 if find_spec("plain.passwords"):

7 # Automatically invalidate sessions on password field change,

8 # if the plain-passwords is installed. You can change this value

9 # if your password field is named differently, or you want

10 # to use a different field to invalidate sessions.

11 AUTH_USER_SESSION_HASH_FIELD: str = "password"

12 else:

13 AUTH_USER_SESSION_HASH_FIELD: str = ""